@@ -51,6 +51,7 @@
 #include "util.h"
 #include "display-private.h"
 #include "errors.h"
+#include "keybindings.h"
 #include "ui.h"
 #include "session.h"
 #include "prefs.h"
@@ -211,6 +212,7 @@ typedef struct
   gboolean composite;
   gboolean no_composite;
   gboolean no_force_fullscreen;
+  gboolean no_keybindings;
 } MetaArguments;
 
 #ifdef HAVE_COMPOSITE_EXTENSIONS
@@ -269,7 +271,7 @@ meta_parse_options (int *argc, char ***argv,
       "FILE"
     },
     {
-      "version", 0, 0, G_OPTION_ARG_NONE,
+      "version", 'v', 0, G_OPTION_ARG_NONE,
       &my_args.print_version,
       N_("Print version"),
       NULL
@@ -298,6 +300,12 @@ meta_parse_options (int *argc, char ***argv,
       N_("Don't make fullscreen windows that are maximized and have no decorations"),
       NULL
     },
+    {
+      "no-keybindings", 0, 0, G_OPTION_ARG_NONE,
+      &my_args.no_keybindings,
+      N_("Have all keybindings disabled on startup"),
+      NULL
+    },
     {NULL}
   };
   GOptionContext *ctx;
@@ -550,6 +558,9 @@ main (int argc, char **argv)
   if (meta_args.no_force_fullscreen)
     meta_prefs_set_force_fullscreen (FALSE);
 
+  if (meta_args.no_keybindings)
+    meta_set_keybindings_disabled (TRUE);
+
   if (!meta_display_open ())
     meta_exit (META_EXIT_ERROR);
 
