@@ -66,6 +66,7 @@ new_meta_strut (int x, int y, int width, int height, int side)
   temporary = g_new (MetaStrut, 1);
   temporary->rect = meta_rect(x, y, width, height);
   temporary->side = side;
+  temporary->edge = META_EDGE_SCREEN;
 
   return temporary;
 }
@@ -207,10 +208,10 @@ test_basic_fitting (void)
     {
       get_random_rect (&temp1);
       get_random_rect (&temp2);
-      g_assert (meta_rectangle_contains_rect (&temp1, &temp2) == FALSE ||
-                meta_rectangle_could_fit_rect (&temp1, &temp2) == TRUE);
-      g_assert (meta_rectangle_contains_rect (&temp2, &temp1) == FALSE ||
-                meta_rectangle_could_fit_rect (&temp2, &temp1) == TRUE);
+      g_assert (!meta_rectangle_contains_rect (&temp1, &temp2) ||
+                meta_rectangle_could_fit_rect (&temp1, &temp2));
+      g_assert (!meta_rectangle_contains_rect (&temp2, &temp1) ||
+                meta_rectangle_could_fit_rect (&temp2, &temp1));
     }
 
   temp1 = meta_rect ( 0, 0, 10, 10);
@@ -294,7 +295,10 @@ get_screen_region (int which)
   ret = NULL;
 
   struts = get_strut_list (which);
-  ret = meta_rectangle_get_minimal_spanning_set_for_region (&basic_rect, struts);
+  ret = meta_rectangle_get_minimal_spanning_set_for_region (&basic_rect,
+                                                            struts,
+                                                            FALSE);
+
   free_strut_list (struts);
 
   return ret;
@@ -690,8 +694,8 @@ test_region_fitting (void)
   for (i = 0; i < NUM_RANDOM_RUNS; i++)
     {
       get_random_rect (&rect);
-      g_assert (meta_rectangle_contained_in_region (region, &rect) == FALSE ||
-                meta_rectangle_could_fit_in_region (region, &rect) == TRUE);
+      g_assert (!meta_rectangle_contained_in_region (region, &rect) ||
+                meta_rectangle_could_fit_in_region (region, &rect));
     }
   g_list_free_full (region, g_free);
 
@@ -744,7 +748,7 @@ test_clamping_to_region (void)
                                                fixed_directions,
                                                &rect,
                                                &min_size);
-      g_assert (meta_rectangle_could_fit_in_region (region, &rect) == TRUE);
+      g_assert (meta_rectangle_could_fit_in_region (region, &rect));
       g_assert (rect.x == temp.x && rect.y == temp.y);
     }
   g_list_free_full (region, g_free);
@@ -854,7 +858,7 @@ test_clipping_to_region (void)
       if (rect_overlaps_region (region, &rect))
         {
           meta_rectangle_clip_to_region (region, 0, &rect);
-          g_assert (meta_rectangle_contained_in_region (region, &rect) == TRUE);
+          g_assert (meta_rectangle_contained_in_region (region, &rect));
         }
     }
   g_list_free_full (region, g_free);
@@ -1101,7 +1105,7 @@ test_find_onscreen_edges (void)
   tmp = g_list_prepend (tmp, new_screen_edge (   0,   20, 0, 1180, left));
 
 #if 0
-  #define FUDGE 50 /* number of edges */
+#define FUDGE 50 /* number of edges */
   char big_buffer1[(EDGE_LENGTH+2)*FUDGE], big_buffer2[(EDGE_LENGTH+2)*FUDGE];
   meta_rectangle_edge_list_to_string (edges, "\n ", big_buffer1);
   meta_rectangle_edge_list_to_string (tmp,   "\n ", big_buffer2);
@@ -1190,7 +1194,7 @@ test_find_nonintersected_xinerama_edges (void)
   tmp = g_list_prepend (tmp, new_xinerama_edge ( 800,   20, 0, 1080, right));
   tmp = g_list_prepend (tmp, new_xinerama_edge ( 800,   20, 0, 1180, left));
 #if 0
-  #define FUDGE 50
+#define FUDGE 50
   char big_buffer1[(EDGE_LENGTH+2)*FUDGE], big_buffer2[(EDGE_LENGTH+2)*FUDGE];
   meta_rectangle_edge_list_to_string (edges, "\n ", big_buffer1);
   meta_rectangle_edge_list_to_string (tmp,   "\n ", big_buffer2);
