@@ -458,13 +458,14 @@ meta_ui_repaint_frame (MetaUI *ui,
 }
 
 void
-meta_ui_apply_frame_shape  (MetaUI  *ui,
-                            Window   xwindow,
-                            int      new_window_width,
-                            int      new_window_height,
-                            gboolean window_has_shape)
+meta_ui_apply_frame_shape  (MetaUI      *ui,
+                            MetaDisplay *display,
+                            Window       xwindow,
+                            int          new_window_width,
+                            int          new_window_height,
+                            gboolean     window_has_shape)
 {
-  meta_frames_apply_shapes (ui->frames, xwindow,
+  meta_frames_apply_shapes (ui->frames, display, xwindow,
                             new_window_width, new_window_height,
                             window_has_shape);
 }
@@ -688,10 +689,12 @@ load_window_icon_from_name (char *name, int size, int scale)
   info = g_desktop_app_info_new (desktop_id);
   gicon = g_app_info_get_icon (G_APP_INFO (info));
   icon_info = gtk_icon_theme_lookup_by_gicon_for_scale (theme, gicon, size, scale, GTK_ICON_LOOKUP_FORCE_SIZE);
+  if (icon_info)
+    {
+      pixbuf = gtk_icon_info_load_icon (icon_info, NULL);
+      g_object_unref (icon_info);
+    }
 
-  pixbuf = gtk_icon_info_load_icon (icon_info, NULL);
-
-  g_object_unref (icon_info);
   g_free (desktop_id);
 
   return pixbuf;
